@@ -63,7 +63,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     def status(self, channel_index: int) -> DwfState:
         """Get the |AnalogOut| instrument channel state.
 
-        Executing this method initiates a status request to the |AnalogOut| instrument and receives its response.
+        This method performs a status request to the |AnalogOut| instrument and receives its response.
 
         Parameters:
             channel_index (int): The output channel for which to get the status.
@@ -121,14 +121,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutWaitInfo(self.hdwf, channel_index, c_secMin, c_secMax)
+        c_wait_duration_min = typespec_ctypes.c_double()
+        c_wait_duration_max = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutWaitInfo(self.hdwf, channel_index, c_wait_duration_min, c_wait_duration_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        return (secMin, secMax)
+        wait_duration_min = c_wait_duration_min.value
+        wait_duration_max = c_wait_duration_max.value
+        return (wait_duration_min, wait_duration_max)
 
     def waitSet(self, channel_index: int, wait_duration: float) -> None:
         """Set the |AnalogOut| channel |Wait:link| state duration, in seconds.
@@ -175,14 +175,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutRunInfo(self.hdwf, channel_index, c_secMin, c_secMax)
+        c_run_duration_min = typespec_ctypes.c_double()
+        c_run_duration_max = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutRunInfo(self.hdwf, channel_index, c_run_duration_min, c_run_duration_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        return (secMin, secMax)
+        run_duration_min = c_run_duration_min.value
+        run_duration_max = c_run_duration_max.value
+        return (run_duration_min, run_duration_max)
 
     def runSet(self, channel_index: int, run_duration: float) -> None:
         """Set the |AnalogOut| channel |Running:link| state duration, in seconds.
@@ -230,12 +230,12 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_secRun = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutRunStatus(self.hdwf, channel_index, c_secRun)
+        c_run_duration_status = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutRunStatus(self.hdwf, channel_index, c_run_duration_status)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secRun = c_secRun.value
-        return secRun
+        run_duration_status = c_run_duration_status.value
+        return run_duration_status
 
     def repeatTriggerSet(self, channel_index: int, repeat_trigger_flag: bool) -> None:
         """Set the |AnalogOut| channel *repeat trigger* setting.
@@ -279,6 +279,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     def repeatInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get |AnalogOut| repeat count range.
 
+        The *repeat count* is the number of times the |AnalogOut| channel will go through the
+        Wait/Running or Armed/Wait/Running state cycles during the output sequence.
+
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
@@ -288,17 +291,20 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_nMin = typespec_ctypes.c_int()
-        c_nMax = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutRepeatInfo(self.hdwf, channel_index, c_nMin, c_nMax)
+        c_repeat_min = typespec_ctypes.c_int()
+        c_repeat_max = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutRepeatInfo(self.hdwf, channel_index, c_repeat_min, c_repeat_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        nMin = c_nMin.value
-        nMax = c_nMax.value
-        return (nMin, nMax)
+        repeat_min = c_repeat_min.value
+        repeat_max = c_repeat_max.value
+        return (repeat_min, repeat_max)
 
     def repeatSet(self, channel_index: int, repeat: int) -> None:
-        """Set the |AnalogOut| repeat count setting.
+        """Set the |AnalogOut| repeat count.
+
+        The *repeat count* is the number of times the |AnalogOut| channel will go through the
+        Wait/Running or Armed/Wait/Running state cycles during the output sequence.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -312,7 +318,10 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def repeatGet(self, channel_index: int) -> int:
-        """Get the |AnalogOut| repeat count setting.
+        """Get the |AnalogOut| repeat count.
+
+        The *repeat count* is the number of times the |AnalogOut| channel will go through the
+        Wait/Running or Armed/Wait/Running state cycles during the output sequence.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -353,7 +362,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     def masterSet(self, channel_index: int, master_channel_index: int) -> None:
         """Set the |AnalogOut| channel master.
 
-        Sets the state machine master channel f the analog output channel.
+        Sets the state machine master channel of the analog output channel.
 
         Parameters:
             channel_index (int): The output channel for which to set the master setting.
@@ -371,7 +380,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel master.
 
         Parameters:
-            channel_index (int): The analog output channel for which to get the status.
+            channel_index (int): The analog output channel for which to get the master channel.
 
         Returns:
             int: The index of the master channel which the channel is configured to follow.
@@ -433,13 +442,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self, channel_index: int) -> DwfTriggerSource:
-        """Get the |AnalogOut| channel trigger source.
+        """Get the currently selected channel trigger source.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            DwfTriggerSource: The currently configured trigger source.
+            DwfTriggerSource: The currently selected channel trigger source.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -452,7 +461,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerSlopeSet(self, channel_index: int, trigger_slope: DwfTriggerSlope) -> None:
-        """Set the |AnalogOut| channel trigger slope.
+        """Select the |AnalogOut| channel trigger slope.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -469,13 +478,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSlopeGet(self, channel_index: int) -> DwfTriggerSlope:
-        """Get the |AnalogOut| channel trigger slope.
+        """Get the currently selected |AnalogOut| channel trigger slope.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            DwfTriggerSlope: The currently configured trigger slope setting.
+            DwfTriggerSlope: The currently selected |AnalogOut| channel trigger slope.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -498,7 +507,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            mode (DwfAnalogOutMode): The mode.
+            mode (DwfAnalogOutMode): The analog output mode to configure.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -551,7 +560,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            idle (DwfAnalogOutIdle): The idle setting.
+            idle (DwfAnalogOutIdle): The idle behavior setting to be configured.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -567,7 +576,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            DwfAnalogOutIdle: The idle behavior.
+            DwfAnalogOutIdle: The |AnalogOut| channel idle behavior setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -605,7 +614,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            limitation (float): The limitation value, in [V] or [A].
+            limitation (float): The limitation value, in Volts or Amps.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -621,7 +630,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            float: The currently configured limitation.
+            float: The currently configured limitation value, in Volts or Amps.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -806,7 +815,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return func
 
     def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get the channel node frequency info for an |AnalogOut| channel node, in Hz.
+        """Get the channel node valid frequency range for an |AnalogOut| channel node, in Hz.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -970,10 +979,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     def nodeOffsetSet(self, channel_index: int, node: DwfAnalogOutNode, offset: float) -> None:
         """Set the offset for an |AnalogOut| channel node, in Volts.
 
+        Note:
+            Configuring the offset of the *Carrier* node takes a noticeable amount of time (100s of milliseconds).
+
         Parameters:
             channel_index (int): The |AnalogOut| channel.
             node (DwfAnalogOutNode): The channel node.
-            offset (float): The channel offset to be configured, in Volt.
+            offset (float): The channel offset to be configured, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1008,8 +1020,8 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         The *symmetry* value alters the waveform shape function of the node.
 
         The *symmetry* value ranges from 0 to 100 for most waveform shape functions, except for the
-        :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAnalogOutFunction.SinePower` waveform shape function.
-        where it ranges from -100 to 100.
+        :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAnalogOutFunction.SinePower` waveform shape function,
+        where it ranges from -100 to +100.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1159,7 +1171,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get data info for an |AnalogOut| channel node, in samples.
+        """Get data range for an |AnalogOut| channel node, in samples.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1216,7 +1228,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[int, int, int]: The status counts.
+            Tuple[int, int, int]: The *free*, *lost*, and *corrupted* status counts, in samples.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1728,7 +1740,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def dataInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get the |AnalogOut| channel data buffer info.
+        """Get the |AnalogOut| channel data buffer range.
 
         Warning:
             **This method is obsolete.**
