@@ -154,22 +154,25 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         Returns:
             str: The 12 hex-digit unique serial number of the Digilent Waveforms device.
 
-            The 'SN:' prefix returned by the underlying C API function is discarded.
+            The 'SN:' prefix returned by the underlying C API function (for most devices) is discarded.
 
         Raises:
             DwfLibraryError: The serial number of the Digilent Waveforms device cannot be retrieved.
-            PyDwfError: The serial number returned by the library isn't of the form 'SN:XXXXXXXXXXXX'.
+            PyDwfError: The serial number of the device is not 12 characters long.
         """
         c_serial = ctypes.create_string_buffer(32)
         result = self.lib.FDwfEnumSN(device_index, c_serial)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         serial = c_serial.value.decode()
-        if not serial.startswith("SN:"):
-            raise PyDwfError("Bad serial number string received: {!r}".format(serial))
-        serial = serial[3:]
+        if serial.startswith("SN:"):
+            # The serial number is usually prefixed with the three-character string "SN:".
+            # The only exception is the serial number of the Analog Discovery Pro devices,
+            # when enumerated from the device itself (in Linux mode).
+            serial = serial[3:]
         if len(serial) != 12:
             raise PyDwfError("Serial number isn't 12 characters: {!r}".format(serial))
+
         return serial
 
     def enumerateConfigurations(self, device_index: int) -> int:
