@@ -56,7 +56,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     def status(self) -> DwfState:
         """Return the status of the |DigitalOut| instrument.
 
-        Executing this method initiates a status request to the |DigitalOut| instrument and receives its response.
+        This method performs a status request to the |DigitalOut| instrument and receives its response.
 
         Returns:
             DwfState: The status of the |DigitalOut| instrument.
@@ -363,10 +363,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get the currently configured |DigitalOut| trigger source.
+        """Get the currently selected instrument trigger source.
 
         Returns:
-            DwfTriggerSource: The currently configured trigger source.
+            DwfTriggerSource: The currently selected instrument trigger source.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -379,10 +379,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
-        """Set the |DigitalOut| trigger slope.
+        """Select the |DigitalOut| instrument trigger slope.
 
         Parameters:
-            trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
+            trigger_slope (DwfTriggerSlope): The trigger slope to be selected.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -392,10 +392,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSlopeGet(self) -> DwfTriggerSlope:
-        """Get the currently configured |DigitalOut| trigger slope.
+        """Get the currently configured |DigitalOut| instrument trigger slope.
 
         Returns:
-            DwfTriggerSlope: The currently configured trigger slope.
+            DwfTriggerSlope: The currently selected |DigitalOut| instrument trigger slope.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -478,7 +478,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def outputGet(self, channel_index: int) -> DwfDigitalOutOutput:
-        """Get currently active |DigitalOut| output  (e.g. Push/Pull, tristate).
+        """Get currently configured |DigitalOut| output (e.g. Push/Pull, tristate).
 
         Parameters:
             channel_index (int): The digital pin.
@@ -497,10 +497,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return output_value
 
     def typeInfo(self, channel_index: int) -> List[DwfDigitalOutType]:
-        """Get valid |DigitalOut| output signal types.
+        """Get a list of valid |DigitalOut| output channel types.
 
         Returns:
-            List[DwfDigitalOutType]: A list of valid digital output types.
+            List[DwfDigitalOutType]: A list of valid digital output channel types.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -514,11 +514,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return type_list
 
     def typeSet(self, channel_index: int, output_type: DwfDigitalOutType) -> None:
-        """Set the |DigitalOut| output signal type.
+        """Select the |DigitalOut| output channel type.
 
         Parameters:
             channel_index (int): The digital pin.
-            output_type (DwfDigitalOutType): The digital output type.
+            output_type (DwfDigitalOutType): The digital output channel type.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -528,13 +528,13 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def typeGet(self, channel_index: int) -> DwfDigitalOutType:
-        """Get the currently configured |DigitalOut| output signal type.
+        """Get the currently selected |DigitalOut| output channel type.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            DwfDigitalOutType: The digital output type.
+            DwfDigitalOutType: The digital output channel type.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -568,7 +568,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
         Parameters:
             channel_index (int): The digital pin.
-            idle_mode (DwfDigitalOutIdle): The idle output value setting.
+            idle_mode (DwfDigitalOutIdle): The idle output value.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -578,13 +578,13 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def idleGet(self, channel_index: int) -> DwfDigitalOutIdle:
-        """Get the currently active idle output value.
+        """Get the currently configured idle output value.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            DwfDigitalOutIdle: The current idle output value setting.
+            DwfDigitalOutIdle: The currently configured idle output value.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
